==> HSROC_2.1.6.tar.gz: HSROC/R/HSROC-internal.R <==
.onAttach <-
function (...) 
{
    date <- date()
    x <- regexpr("[0-9]{4}", date)
    this.year <- substr(date, x[1], x[1] + attr(x, "match.length") - 
        1)
    packageStartupMessage("##\n## Hierarchical Summary Receiver Operating Characteristic package (HSROC)")
    packageStartupMessage("## Copyright (C) 2010-", this.year, 
        " Ian Schiller and Nandini Dendukuri ", sep = "")
    packageStartupMessage("##\n## Development of HSROC package was supported by grants from the ")
    packageStartupMessage("## Canadian Institutes of Health Research (MOP #89857) ")
    packageStartupMessage("## and the Fonds de la Recherche en Sant Qubec. ")
}
.Random.seed <-
c(403L, 230L, 1372049589L, 925173903L, -1998544302L, -1318532289L, 
-187330408L, 821848289L, 333724723L, -1742175014L, -1670507997L, 
260919997L, -540242618L, -932994863L, 827831542L, -723132455L, 
-339748292L, 1982036953L, 756122473L, 1736455297L, -1156930036L, 
2097164777L, 1945259673L, -1846993696L, -2124202927L, 819988589L, 
833911075L, -123999540L, -280265927L, 1579090988L, -1527569905L, 
419187609L, 168276664L, -1200208602L, 458677161L, -868638674L, 
46314374L, 735814932L, 434730401L, -286256228L, 1847410312L, 
2104773276L, 265237388L, 1475856929L, -1036924760L, -660339304L, 
-141946826L, -299886632L, 1874857580L, 319791778L, -38329116L, 
-428725518L, 1855281431L, -699352263L, -2140178396L, -581327350L, 
833689943L, 1341461913L, -37903730L, 1921326304L, -56509315L, 
-1543577835L, 1388208388L, -616439088L, -1965882559L, 1749845477L, 
981924643L, 1773838529L, -961953330L, -257959485L, 1470422931L, 
-368748316L, 614546562L, 163348534L, 699265524L, -648364237L, 
871200184L, -73588683L, 264439415L, -752514688L, 1458320791L, 
-1464255638L, -298011141L, 1270259806L, 1614437630L, -407275093L, 
-887918505L, 1702702817L, -202894482L, 902566543L, 443918310L, 
1892766441L, -288053886L, -22982288L, -647898825L, -1335115445L, 
1041513130L, -1821101975L, -475219760L, 2093641297L, 1394187445L, 
1866774388L, -1674485255L, -132143326L, 945566446L, 1560928424L, 
-102025391L, 186129230L, -193249399L, -2032879911L, -2109325794L, 
948316478L, -713724617L, -79102732L, 1244613716L, -1402426136L, 
-538835066L, 1306733579L, 1751359005L, -1912584601L, 1376863749L, 
-1930057586L, -1740211983L, -1717145671L, 1709421442L, -1215754905L, 
-1081840967L, -1401593060L, -1097684881L, 16996720L, -1783235836L, 
1192344796L, 1112877223L, -1033652329L, 53432628L, 1032147263L, 
-1691198341L, -1323261012L, 2136467900L, -1575789340L, 1807886607L, 
1984958467L, -1300196439L, -115207730L, 1963531591L, 69966989L, 
1147566526L, 785813319L, 465838745L, -1958872489L, 933696618L, 
912925292L, -1546981686L, -1608069233L, 1263033576L, -507121173L, 
-130559238L, -198576186L, -1786751238L, -936229036L, 1960531837L, 
123005005L, -1732780536L, -1604107338L, -1089812215L, -151823753L, 
-1456177856L, -1185153715L, 1926821472L, 696354573L, -1308618088L, 
-289918368L, 1012412078L, -970841609L, -725064041L, 1466291087L, 
113186366L, 319316432L, 1530244450L, -1384423279L, 1496676883L, 
1303394127L, -1128313646L, -1766087862L, 947671725L, 326306702L, 
1376914329L, 713634640L, 1177746522L, 115535121L, 345144014L, 
1190137014L, -630835528L, -601546159L, -2051556824L, -1419775223L, 
1629605135L, 337862775L, -1958568704L, 634908463L, -1656920962L, 
236793203L, 491415931L, -496191948L, -2064571396L, -1505198982L, 
-1831254659L, -1491505793L, 9184081L, -168825289L, 2101463508L, 
-1411925360L, 1674981337L, 2033258647L, -160752992L, -1398713650L, 
-375140033L, 19330780L, -1958001581L, 1978493277L, 1746651429L, 
-197065865L, 1202956398L, -1663538753L, -1097126168L, 1522195859L, 
-593523166L, -686666205L, -1470305026L, 1305587175L, 838580051L, 
847531690L, -432962742L, 375031867L, -1847587475L, -612494451L, 
1095050969L, -1349019757L, 747853615L, -1621736505L, 1622586137L, 
45898426L, -328336706L, 1236246475L, -1801489583L, 1118411731L, 
556200164L, 1582856453L, -1086400950L, -2060490369L, 1942547804L, 
-788718407L, 1903481767L, -671568105L, 1299495357L, -286635110L, 
-434855811L, -1579412640L, -1499713521L, 1505379471L, 1406682917L, 
1181623850L, -531862368L, 1391758801L, 1064157067L, 1696098661L, 
-1728288547L, 1102341578L, 1415203994L, 2052003504L, 2145558819L, 
-951208066L, -1014221393L, -856164067L, 55305089L, -805002525L, 
592881331L, -184120197L, -1153123595L, -97289412L, -1258536387L, 
-1370236617L, 352933462L, -453892920L, 609196026L, 621244376L, 
931760654L, -988325843L, 1818036176L, -1040404167L, 1408931251L, 
140340237L, 1951676487L, 1835805882L, 640399196L, -633475765L, 
1200522258L, 2135230875L, 1857072866L, -2130332481L, 1583446448L, 
727127007L, -1200782144L, -1346180340L, 1606411468L, 1545470299L, 
696213262L, -1870292653L, 1349965841L, -2084231911L, 1586412234L, 
728375471L, -253087359L, 271436344L, -222774649L, 249734815L, 
1931556580L, -1735270519L, 1548161566L, -1221954431L, -210298295L, 
-1020554321L, -2066923745L, -580012146L, -477948065L, -385046333L, 
1631550599L, 870325833L, -1375896859L, -614387389L, -668068902L, 
-1405776833L, 1087040544L, 266985472L, 1563579102L, -1142523816L, 
36129149L, -2100540986L, -360423178L, -638846864L, 637318955L, 
-1345503831L, 1718584271L, -389962255L, -234194712L, -212558865L, 
1136036185L, 1421437229L, -1334787114L, -472091132L, 1215110240L, 
1257658819L, 1058886592L, 2031463693L, 774464101L, -353934180L, 
-1775648790L, -883842454L, -1373277504L, 695460475L, -1734656470L, 
681249118L, -683891235L, -686198543L, -2024938014L, -1358637539L, 
715363750L, 1849222258L, -989522210L, 1198645231L, 147942843L, 
-1471215655L, 679272297L, -2065751143L, -1099487093L, 645293556L, 
1080025950L, -830640455L, 422281851L, 597417675L, -408866115L, 
-198930283L, -1618800402L, 158330363L, 1737476422L, 2119553750L, 
-1359456151L, 1642888380L, 1008610521L, 472361232L, -434661517L, 
-1305196945L, 178481352L, 1304226567L, 394863098L, -507650125L, 
-611266218L, -1675089874L, -1310917039L, 556582191L, 983416317L, 
-2003754338L, 193089523L, -355363372L, 1871073144L, -55846145L, 
2033809401L, -1543356465L, 625312855L, -289732126L, -645141684L, 
245337529L, 902743846L, -1946426201L, -398594570L, 1687550071L, 
-920467760L, 465698055L, -1173045995L, -1344722112L, -461200275L, 
-860795503L, -738247070L, -1709271729L, -314571491L, -916231234L, 
2108510548L, 1312849101L, -2085917812L, 1784685901L, 1307049970L, 
-554035694L, 1769668178L, 1141484860L, 59470019L, -942069682L, 
1731405264L, 1778286680L, -49606126L, 190224117L, -1293092400L, 
-1954183175L, 832296130L, 1312204555L, -140434698L, -987874164L, 
301804416L, 1336727892L, 1226882914L, 192674644L, 604569046L, 
-834929996L, -1738650639L, 513600493L, -620778751L, 1921948320L, 
340759966L, 626860255L, -1957294286L, -1940206159L, 792252892L, 
524986624L, 858133796L, 1355154953L, -750223174L, 689648710L, 
-1975552609L, 567943889L, -140460246L, 1055003073L, 1093449908L, 
1095654213L, 1249414432L, -1718484985L, 69084537L, -1456514964L, 
1248513903L, 2058868306L, -384490455L, 1020637407L, -1224605596L, 
998801394L, -323807580L, 281671908L, -571466507L, -336207059L, 
-1246814905L, 430177523L, 254556694L, -1560403469L, 1727912803L, 
273931809L, 1135156507L, -1155294876L, 970245777L, -1777463576L, 
-1216609037L, 119623338L, -828880500L, 247483475L, 1351982384L, 
1314928151L, 1873900935L, -678652299L, 573255418L, -1549126916L, 
1696100212L, 475359125L, 1203109850L, 1725188509L, -1038513899L, 
488382252L, 1212005972L, -826953320L, -1022853575L, 1926568498L, 
345739593L, -153274978L, -908826333L, -581179857L, -1097512554L, 
690433535L, -274151505L, 1837958712L, 192643256L, -1940542529L, 
-2117414579L, 1119319864L, 1371389805L, -450220195L, -1929032301L, 
218498121L, -587005058L, 1682789327L, 1810369081L, 897051675L, 
2145055458L, -188593041L, 1777247750L, -292216083L, 678887638L, 
-612351494L, 1008674160L, 1018609111L, 826106062L, -25831419L, 
-1800655608L, 538472436L, -1058916352L, 506574666L, 494627068L, 
211536384L, 1728031725L, 1009677671L, 860742504L, -68343002L, 
-1809606189L, -974115739L, 1585844738L, 625542408L, -1458120375L, 
-406171636L, 828181850L, 1357464211L, 879289399L, -803741612L, 
-214548957L, -111659154L, -933695185L, -817459178L, -110723672L, 
-1983592608L, 688391556L, 1567548245L, 195757954L, 1421054495L, 
137108674L, 1156019169L, 1431127174L, 1714172971L, -1235653224L, 
-873833328L, -609314794L, -1749653130L, 903568534L, -118007407L, 
1481142977L, -775981350L, 1780586239L, -871536008L, 1617233693L, 
118463566L, -484878879L, 385673676L, 980238017L, 1161006773L, 
1842638016L, -211410594L, -1118301610L, 2102424211L, 1459370222L, 
-565485807L, -2014252028L, 939617357L, -2129899403L, 1609017948L, 
-1116186491L, 482558338L, 506694145L, 381030619L, -1242668468L, 
-1875358514L, 409092867L, 995842898L, -308481253L, 1908748090L, 
401645364L, 1539587785L, 1181447737L, 1559715450L, -368454879L, 
1229681586L, -417837052L, 185024324L, 819043294L, 3647188L)

==> HSROC_2.1.8.tar.gz: HSROC/R/HSROC-internal.R <==
.onAttach <-
function (...) 
{
    date <- date()
    x <- regexpr("[0-9]{4}", date)
    this.year <- substr(date, x[1], x[1] + attr(x, "match.length") - 
        1)
    packageStartupMessage("##\n## Hierarchical Summary Receiver Operating Characteristic package (HSROC)")
    packageStartupMessage("## Copyright (C) 2010-", this.year, 
        " Ian Schiller and Nandini Dendukuri ", sep = "")
    packageStartupMessage("##\n## Development of HSROC package was supported by grants from the ")
    packageStartupMessage("## Canadian Institutes of Health Research (MOP #89857) ")
    packageStartupMessage("## and the Fonds de la Recherche en Sant<U+00E9> Qu<U+00E9>bec. ")
}
.Random.seed <-
c(403L, 230L, 1372049589L, 925173903L, -1998544302L, -1318532289L, 
-187330408L, 821848289L, 333724723L, -1742175014L, -1670507997L, 
260919997L, -540242618L, -932994863L, 827831542L, -723132455L, 
-339748292L, 1982036953L, 756122473L, 1736455297L, -1156930036L, 
2097164777L, 1945259673L, -1846993696L, -2124202927L, 819988589L, 
833911075L, -123999540L, -280265927L, 1579090988L, -1527569905L, 
419187609L, 168276664L, -1200208602L, 458677161L, -868638674L, 
46314374L, 735814932L, 434730401L, -286256228L, 1847410312L, 
2104773276L, 265237388L, 1475856929L, -1036924760L, -660339304L, 
-141946826L, -299886632L, 1874857580L, 319791778L, -38329116L, 
-428725518L, 1855281431L, -699352263L, -2140178396L, -581327350L, 
833689943L, 1341461913L, -37903730L, 1921326304L, -56509315L, 
-1543577835L, 1388208388L, -616439088L, -1965882559L, 1749845477L, 
981924643L, 1773838529L, -961953330L, -257959485L, 1470422931L, 
-368748316L, 614546562L, 163348534L, 699265524L, -648364237L, 
871200184L, -73588683L, 264439415L, -752514688L, 1458320791L, 
-1464255638L, -298011141L, 1270259806L, 1614437630L, -407275093L, 
-887918505L, 1702702817L, -202894482L, 902566543L, 443918310L, 
1892766441L, -288053886L, -22982288L, -647898825L, -1335115445L, 
1041513130L, -1821101975L, -475219760L, 2093641297L, 1394187445L, 
1866774388L, -1674485255L, -132143326L, 945566446L, 1560928424L, 
-102025391L, 186129230L, -193249399L, -2032879911L, -2109325794L, 
948316478L, -713724617L, -79102732L, 1244613716L, -1402426136L, 
-538835066L, 1306733579L, 1751359005L, -1912584601L, 1376863749L, 
-1930057586L, -1740211983L, -1717145671L, 1709421442L, -1215754905L, 
-1081840967L, -1401593060L, -1097684881L, 16996720L, -1783235836L, 
1192344796L, 1112877223L, -1033652329L, 53432628L, 1032147263L, 
-1691198341L, -1323261012L, 2136467900L, -1575789340L, 1807886607L, 
1984958467L, -1300196439L, -115207730L, 1963531591L, 69966989L, 
1147566526L, 785813319L, 465838745L, -1958872489L, 933696618L, 
912925292L, -1546981686L, -1608069233L, 1263033576L, -507121173L, 
-130559238L, -198576186L, -1786751238L, -936229036L, 1960531837L, 
123005005L, -1732780536L, -1604107338L, -1089812215L, -151823753L, 
-1456177856L, -1185153715L, 1926821472L, 696354573L, -1308618088L, 
-289918368L, 1012412078L, -970841609L, -725064041L, 1466291087L, 
113186366L, 319316432L, 1530244450L, -1384423279L, 1496676883L, 
1303394127L, -1128313646L, -1766087862L, 947671725L, 326306702L, 
1376914329L, 713634640L, 1177746522L, 115535121L, 345144014L, 
1190137014L, -630835528L, -601546159L, -2051556824L, -1419775223L, 
1629605135L, 337862775L, -1958568704L, 634908463L, -1656920962L, 
236793203L, 491415931L, -496191948L, -2064571396L, -1505198982L, 
-1831254659L, -1491505793L, 9184081L, -168825289L, 2101463508L, 
-1411925360L, 1674981337L, 2033258647L, -160752992L, -1398713650L, 
-375140033L, 19330780L, -1958001581L, 1978493277L, 1746651429L, 
-197065865L, 1202956398L, -1663538753L, -1097126168L, 1522195859L, 
-593523166L, -686666205L, -1470305026L, 1305587175L, 838580051L, 
847531690L, -432962742L, 375031867L, -1847587475L, -612494451L, 
1095050969L, -1349019757L, 747853615L, -1621736505L, 1622586137L, 
45898426L, -328336706L, 1236246475L, -1801489583L, 1118411731L, 
556200164L, 1582856453L, -1086400950L, -2060490369L, 1942547804L, 
-788718407L, 1903481767L, -671568105L, 1299495357L, -286635110L, 
-434855811L, -1579412640L, -1499713521L, 1505379471L, 1406682917L, 
1181623850L, -531862368L, 1391758801L, 1064157067L, 1696098661L, 
-1728288547L, 1102341578L, 1415203994L, 2052003504L, 2145558819L, 
-951208066L, -1014221393L, -856164067L, 55305089L, -805002525L, 
592881331L, -184120197L, -1153123595L, -97289412L, -1258536387L, 
-1370236617L, 352933462L, -453892920L, 609196026L, 621244376L, 
931760654L, -988325843L, 1818036176L, -1040404167L, 1408931251L, 
140340237L, 1951676487L, 1835805882L, 640399196L, -633475765L, 
1200522258L, 2135230875L, 1857072866L, -2130332481L, 1583446448L, 
727127007L, -1200782144L, -1346180340L, 1606411468L, 1545470299L, 
696213262L, -1870292653L, 1349965841L, -2084231911L, 1586412234L, 
728375471L, -253087359L, 271436344L, -222774649L, 249734815L, 
1931556580L, -1735270519L, 1548161566L, -1221954431L, -210298295L, 
-1020554321L, -2066923745L, -580012146L, -477948065L, -385046333L, 
1631550599L, 870325833L, -1375896859L, -614387389L, -668068902L, 
-1405776833L, 1087040544L, 266985472L, 1563579102L, -1142523816L, 
36129149L, -2100540986L, -360423178L, -638846864L, 637318955L, 
-1345503831L, 1718584271L, -389962255L, -234194712L, -212558865L, 
1136036185L, 1421437229L, -1334787114L, -472091132L, 1215110240L, 
1257658819L, 1058886592L, 2031463693L, 774464101L, -353934180L, 
-1775648790L, -883842454L, -1373277504L, 695460475L, -1734656470L, 
681249118L, -683891235L, -686198543L, -2024938014L, -1358637539L, 
715363750L, 1849222258L, -989522210L, 1198645231L, 147942843L, 
-1471215655L, 679272297L, -2065751143L, -1099487093L, 645293556L, 
1080025950L, -830640455L, 422281851L, 597417675L, -408866115L, 
-198930283L, -1618800402L, 158330363L, 1737476422L, 2119553750L, 
-1359456151L, 1642888380L, 1008610521L, 472361232L, -434661517L, 
-1305196945L, 178481352L, 1304226567L, 394863098L, -507650125L, 
-611266218L, -1675089874L, -1310917039L, 556582191L, 983416317L, 
-2003754338L, 193089523L, -355363372L, 1871073144L, -55846145L, 
2033809401L, -1543356465L, 625312855L, -289732126L, -645141684L, 
245337529L, 902743846L, -1946426201L, -398594570L, 1687550071L, 
-920467760L, 465698055L, -1173045995L, -1344722112L, -461200275L, 
-860795503L, -738247070L, -1709271729L, -314571491L, -916231234L, 
2108510548L, 1312849101L, -2085917812L, 1784685901L, 1307049970L, 
-554035694L, 1769668178L, 1141484860L, 59470019L, -942069682L, 
1731405264L, 1778286680L, -49606126L, 190224117L, -1293092400L, 
-1954183175L, 832296130L, 1312204555L, -140434698L, -987874164L, 
301804416L, 1336727892L, 1226882914L, 192674644L, 604569046L, 
-834929996L, -1738650639L, 513600493L, -620778751L, 1921948320L, 
340759966L, 626860255L, -1957294286L, -1940206159L, 792252892L, 
524986624L, 858133796L, 1355154953L, -750223174L, 689648710L, 
-1975552609L, 567943889L, -140460246L, 1055003073L, 1093449908L, 
1095654213L, 1249414432L, -1718484985L, 69084537L, -1456514964L, 
1248513903L, 2058868306L, -384490455L, 1020637407L, -1224605596L, 
998801394L, -323807580L, 281671908L, -571466507L, -336207059L, 
-1246814905L, 430177523L, 254556694L, -1560403469L, 1727912803L, 
273931809L, 1135156507L, -1155294876L, 970245777L, -1777463576L, 
-1216609037L, 119623338L, -828880500L, 247483475L, 1351982384L, 
1314928151L, 1873900935L, -678652299L, 573255418L, -1549126916L, 
1696100212L, 475359125L, 1203109850L, 1725188509L, -1038513899L, 
488382252L, 1212005972L, -826953320L, -1022853575L, 1926568498L, 
345739593L, -153274978L, -908826333L, -581179857L, -1097512554L, 
690433535L, -274151505L, 1837958712L, 192643256L, -1940542529L, 
-2117414579L, 1119319864L, 1371389805L, -450220195L, -1929032301L, 
218498121L, -587005058L, 1682789327L, 1810369081L, 897051675L, 
2145055458L, -188593041L, 1777247750L, -292216083L, 678887638L, 
-612351494L, 1008674160L, 1018609111L, 826106062L, -25831419L, 
-1800655608L, 538472436L, -1058916352L, 506574666L, 494627068L, 
211536384L, 1728031725L, 1009677671L, 860742504L, -68343002L, 
-1809606189L, -974115739L, 1585844738L, 625542408L, -1458120375L, 
-406171636L, 828181850L, 1357464211L, 879289399L, -803741612L, 
-214548957L, -111659154L, -933695185L, -817459178L, -110723672L, 
-1983592608L, 688391556L, 1567548245L, 195757954L, 1421054495L, 
137108674L, 1156019169L, 1431127174L, 1714172971L, -1235653224L, 
-873833328L, -609314794L, -1749653130L, 903568534L, -118007407L, 
1481142977L, -775981350L, 1780586239L, -871536008L, 1617233693L, 
118463566L, -484878879L, 385673676L, 980238017L, 1161006773L, 
1842638016L, -211410594L, -1118301610L, 2102424211L, 1459370222L, 
-565485807L, -2014252028L, 939617357L, -2129899403L, 1609017948L, 
-1116186491L, 482558338L, 506694145L, 381030619L, -1242668468L, 
-1875358514L, 409092867L, 995842898L, -308481253L, 1908748090L, 
401645364L, 1539587785L, 1181447737L, 1559715450L, -368454879L, 
1229681586L, -417837052L, 185024324L, 819043294L, 3647188L)
